@@ -1,18 +1,19 @@
-# Copyrights 2013-2014 by [Mark Overmeer].
+# Copyrights 2013-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package Log::Report::Minimal;
 use vars '$VERSION';
-$VERSION = '1.00';
+$VERSION = '1.03';
 
 use base 'Exporter';
 
 use Log::Report::Util;
 use List::Util        qw/first/;
+use Scalar::Util      qw/blessed/;
 
 use Log::Report::Minimal::Domain ();
 
@@ -58,7 +59,18 @@ sub _interpolate(@)
 
 
 sub textdomain($@)
-{   my $name   = shift;
+{   if(@_==1 && blessed $_[0])
+    {   my $domain = shift;
+        return $textdomains{$domain->name} = $domain;
+    }
+
+    if(@_==2)
+    {    # used for 'maintenance' and testing
+        return delete $textdomains{$_[0]} if $_[1] eq 'DELETE';
+        return $textdomains{$_[0]} if $_[1] eq 'EXISTS';
+    }
+
+    my $name   = shift;
     my $domain = $textdomains{$name}
       ||= Log::Report::Minimal::Domain->new(name => $name);
 
@@ -136,8 +148,8 @@ sub __($) { shift }
 
 
 sub __x($@)
-{   @_%2 or error __x"even length parameter list for __x at {where}",
-        where => join(' line ', (caller)[1,2]);
+{   @_%2 or error __x"even length parameter list for __x at {where}"
+      , where => join(' line ', (caller)[1,2]);
 
     _interpolate @_, _expand => 1;
 } 
